@@ -33,7 +33,6 @@ fn k_min_max_capacity(num_h3indexes: usize, k_min: u32, k_max: u32) -> PyResult<
 #[allow(clippy::type_complexity)]
 #[pyfunction]
 fn grid_disk_distances(
-    py: Python,
     h3index_arr: PyReadonlyArray1<u64>,
     k_min: u32,
     k_max: u32,
@@ -53,16 +52,18 @@ fn grid_disk_distances(
         builder.build_grid_disk(&cell).into_pyresult()?;
         for (ring_cell, ring_cell_k) in &mut builder {
             center_h3indexes.push(*h3index);
-            ring_h3indexes.push(ring_cell.h3index() as u64);
+            ring_h3indexes.push(ring_cell.h3index());
             ks.push(ring_cell_k);
         }
     }
 
-    Ok((
-        center_h3indexes.to_pyarray(py).to_owned(),
-        ring_h3indexes.to_pyarray(py).to_owned(),
-        ks.to_pyarray(py).to_owned(),
-    ))
+    Ok(Python::with_gil(|py| {
+        (
+            center_h3indexes.to_pyarray(py).to_owned(),
+            ring_h3indexes.to_pyarray(py).to_owned(),
+            ks.to_pyarray(py).to_owned(),
+        )
+    }))
 }
 
 enum KAggregationMode {
@@ -84,7 +85,6 @@ impl FromStr for KAggregationMode {
 
 #[allow(clippy::type_complexity)]
 fn kring_distances_agg_internal<A: Fn(&mut u32, u32)>(
-    py: Python,
     h3indexes: ArrayView1<u64>,
     k_min: u32,
     k_max: u32,
@@ -103,14 +103,14 @@ fn kring_distances_agg_internal<A: Fn(&mut u32, u32)>(
         builder.build_grid_disk(&cell).into_pyresult()?;
         for (ring_cell, ring_cell_k) in &mut builder {
             cellmap
-                .entry(ring_cell.h3index() as u64)
+                .entry(ring_cell.h3index())
                 .and_modify(|existing_ring_cell_k| agg_closure(existing_ring_cell_k, ring_cell_k))
                 .or_insert(ring_cell_k);
         }
     }
 
     let capacity = cellmap.len();
-    let (h3indexes_out, k_out) = cellmap.drain().fold(
+    let (h3indexes_out, k_out) = cellmap.into_iter().fold(
         (Vec::with_capacity(capacity), Vec::with_capacity(capacity)),
         |mut vecs, (h3index, k)| {
             vecs.0.push(h3index);
@@ -118,10 +118,12 @@ fn kring_distances_agg_internal<A: Fn(&mut u32, u32)>(
             vecs
         },
     );
-    Ok((
-        h3indexes_out.to_pyarray(py).to_owned(),
-        k_out.to_pyarray(py).to_owned(),
-    ))
+    Ok(Python::with_gil(|py| {
+        (
+            h3indexes_out.to_pyarray(py).to_owned(),
+            k_out.to_pyarray(py).to_owned(),
+        )
+    }))
 }
 
 /// Vectorized grid-disk building, with the k-values of the rings being aggregated to their `min` or
@@ -129,7 +131,6 @@ fn kring_distances_agg_internal<A: Fn(&mut u32, u32)>(
 #[allow(clippy::type_complexity)]
 #[pyfunction]
 fn grid_disk_distances_agg(
-    py: Python,
     h3index_arr: PyReadonlyArray1<u64>,
     k_min: u32,
     k_max: u32,
@@ -148,12 +149,11 @@ fn grid_disk_distances_agg(
             }
         },
     };
-    kring_distances_agg_internal(py, h3indexes, k_min, k_max, agg_closure)
+    kring_distances_agg_internal(h3indexes, k_min, k_max, agg_closure)
 }
 
 #[pyfunction]
 fn change_resolution(
-    py: Python,
     h3index_arr: PyReadonlyArray1<u64>,
     h3_resolution: u8,
 ) -> PyResult<Py<PyArray1<u64>>> {
@@ -170,13 +170,12 @@ fn change_resolution(
             out_vec.push(maybe_cell.into_pyresult()?.h3index())
         }
     }
-    Ok(out_vec.to_pyarray(py).to_owned())
+    Ok(Python::with_gil(|py| out_vec.to_pyarray(py).to_owned()))
 }
 
 #[allow(clippy::type_complexity)]
 #[pyfunction]
 fn change_resolution_paired(
-    py: Python,
     h3index_arr: PyReadonlyArray1<u64>,
     h3_resolution: u8,
 ) -> PyResult<(Py<PyArray1<u64>>, Py<PyArray1<u64>>)> {
@@ -193,14 +192,16 @@ fn change_resolution_paired(
         out_vec_before.reserve(iter.size_hint().0);
         for pair in iter {
             let (before_cell, after_cell) = pair.into_pyresult()?;
-            out_vec_before.push(before_cell.h3index() as u64);
-            out_vec_after.push(after_cell.h3index() as u64);
+            out_vec_before.push(before_cell.h3index());
+            out_vec_after.push(after_cell.h3index());
         }
     }
-    Ok((
-        out_vec_before.to_pyarray(py).to_owned(),
-        out_vec_after.to_pyarray(py).to_owned(),
-    ))
+    Ok(Python::with_gil(|py| {
+        (
+            out_vec_before.to_pyarray(py).to_owned(),
+            out_vec_after.to_pyarray(py).to_owned(),
+        )
+    }))
 }
 
 pub fn init_op_submodule(m: &PyModule) -> PyResult<()> {
