@@ -1,6 +1,7 @@
 import geopandas as gpd
 from shapely.geometry import Point, GeometryCollection
 from h3ronpy.vector import geodataframe_to_h3
+import pytest
 
 
 def test_geodataframe_to_h3():
@@ -11,11 +12,13 @@ def test_geodataframe_to_h3():
     assert df.dtypes["h3index"] == "uint64"
 
 
-def test_empty_geometry_omitted():
-    gdf = gpd.GeoDataFrame({"geometry": [Point(),]}, crs="epsg:4326")
-    df = geodataframe_to_h3(gdf, 4)
-    assert len(df) == 0
-
+def test_empty_geometrycollection_omitted():
     gdf = gpd.GeoDataFrame({"geometry": [GeometryCollection(),]}, crs="epsg:4326")
     df = geodataframe_to_h3(gdf, 4)
     assert len(df) == 0
+
+def test_fail_on_empty_point():
+    gdf = gpd.GeoDataFrame({"geometry": [Point(),]}, crs="epsg:4326")
+    with pytest.raises(Exception):
+        df = geodataframe_to_h3(gdf, 4)
+
